Easymode, Quickly build backends for flash/flex websites with django
====================================================================

With easymode you can create backends for dynamic flash/flex websites.
Easymode makes internationalization simple and outputs xml by
default. To tailor the xml to your application, you can transform
it using xslt templates, which easymode integrates.

For more info, look at http://packages.python.org/django-easymode/details.html

Documentation
-------------

To view the documentation:

go to http://packages.python.org/django-easymode/

To build the documentation:

- make sure the requirements are installed ``pip install -r requirements.txt``
- cd to ``docs``
- type: ``make html``
- now your documentation is in: ``docs/_build/html/``

Help
----

If you need help, please send your questions to the mailing list at
easymode@librelist.com.

License
-------

If not otherwise specified, files in this project fall under the following license::

   Easymode, Quickly build backends for flash/flex websites with django
   Copyright (C) 2009  Lars van de Kerkhof
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.